@@ -40,7 +40,7 @@
 
 /* RCS version string for later identification using rcs ident {{{*/
 #ifndef lint
-static volatile const char *RCSid = "@(#) $Id: tpb.c,v 1.11 2002/07/23 13:05:01 mbr Exp $";
+static volatile const char *RCSid = "@(#) $Id: tpb.c,v 1.11.2.2 2002/09/25 12:07:52 mbr Exp $";
 #endif
 /* }}} */
 
@@ -81,7 +81,7 @@ int main(int argc, char **argv)/*{{{*/
 
 #ifdef HAVE_LIBXOSD
 	/* initialize osd */
-	if(cfg.osd) osdptr=xosd_init(cfg.osdfont, cfg.osdcolor, cfg.osdtimeout, cfg.osdpos, cfg.osdoffset, 0);
+	if(cfg.osd) osdptr=xosd_init(cfg.osdfont, cfg.osdcolor, cfg.osdtimeout, cfg.osdpos, cfg.osdoffset, 0, 2);
 #endif /* HAVE_LIBXOSD */
 
 	/* if we use OSS mixer initialize the value of vl */
@@ -184,10 +184,10 @@ int main(int argc, char **argv)/*{{{*/
 
 		/* determine the state of power {{{ */
 		if(tpbs.ac != ltpbs.ac) {
-			if(cfg.verbose) printf("Power line changed: %s\n", tpbs.ac ? "AC connected" : "AC disconnected");
+			if(cfg.verbose) printf("Power line changed: %s\n", tpbs.ac ? "AC disconnected" : "AC connected");
 #ifdef HAVE_LIBXOSD
 			if(osdptr) {
-					xosd_display(osdptr, 0, XOSD_string, tpbs.ac ? "AC connected" : "AC disconnected");
+					xosd_display(osdptr, 0, XOSD_string, tpbs.ac ? "AC disconnected" : "AC connected");
 					xosd_display(osdptr, 1, XOSD_string, "");
 			}
 #endif /* HAVE_LIBXOSD */
