@@ -21,6 +21,8 @@
 #ifndef __TPB_H__
 #define __TPB_H__
 
+#define MAXVOLUME 100
+
 typedef struct {
 	char tpb; /* ThinkPad button */
 	char kt;  /* ThinkLight */
@@ -38,6 +40,8 @@ typedef struct {
 
 int get_state(t_tpb *tpbs);
 int fork_app(char *cmd);
+void set_vl(void);
+int set_mixer(int change);
 
 #endif /* __TPB_H__*/
 
